==> apoplast-0.0.5.tar.gz: apoplast-0.0.5/structures/modules/apoplast/shows/natures/pattern.r.HTML.py <==



pattern:
{
	"emblem": "",
	
	"affiliate": {
		"links": []
	},
	
	"USDA_food": {},
	"NIH_supp": {},
	
	"nature": {
		"treasure": {
			"name": "",
			"UPC": "",
			"DSLD ID": "",
			"FDC ID": ""
		},
		"brand": {
			"name": ""
		},

		"measures": {
			
			#
			#	if a supp
			#
			"form": "form": {
				"unit": "Tablet",
				"amount": "90",
				
				#
				#	
				#
				"estimate": "no",
				"rounded": "up"
			},
			
			#
			#	For NIH supps these are necessary for
			#	calculating the mass.
			#
			"defined": {
				"servings per container": ""
			},
			"energy": {
				"per package": {
					"calories": {
						"decimal string: "",
						"fraction string": ""
					},
					"joules": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			
			"mass": {
				"per package": {
					"grams": {
						"decimal string: "",
						"fraction string": ""
					},
					"pounds": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			"mass, including mass equivalents": {
				"in people": {
					"per package": {
						"grams": {
							"decimal string: "",
							"fraction string": ""
						},
						"pounds": {
							"decimal string: "",
							"fraction string": ""
						}
					}
				}
			},
			"mass equivalents": {
				"per package": {
					"grams": {
						"decimal string: "",
						"fraction string": ""
					},
					"pounds": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			
			"volume": {
				"per package": {
					"liters": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			}
		},
		
		
		"measured ingredients": {
			"grove": [{
				"name": "vitamin b",
				
				
				#
				#	essential nutrient
				#
				"essential": {
					"names": [ "vitamin b", "cobalamin" ],
					"includes": []
				},
				
				
				"measures": {
					#
					#	
					#
					"mass": {
						"per package": {
							"grams": {
								"decimal string": "",
								"fraction string": ""
							},
							"ounces": {
								
							}
						}
					},
					
					#
					#	"equivalents"
					#
					"mass equivalent": {
						"per package": {
							"grams": {
								"equivalent": "DFE",
								"decimal string": "",
								"fraction string": ""
							}
						}
					},
					
					#
					#	if IU
					#
					"biological activity": {
						"per package": {
							"IU": {
								"decimal string": "",
								"fraction string": ""
							}
						}
					}
				}
			}]
		},
		
		"unmeasured ingredients": {

			#
			#	USDA sends a string "ingredients"
			#
			"string": "",

			#
			#	NIH sends a list of "otherIngredients"
			#
			"list": []
		},

		"reference": [],
	},		


	#
	#	unique sections
	#

	#
	#	unique to NIH supps
	#
	"statements": []
	
	
	

	"calculated": {
		
		
		
		
		#
		#	this intermediary might be necessary
		#
		"quantified essential nutrients list": [],
		
		
		"quantified essential nutrients grove": [],
		
		#
		#	priority 2:
		#	
		#	based on shape.current_1
		#
		"quantified ingredients current": [],
	}
}

==> apoplast-0.0.6.tar.gz: apoplast-0.0.6/structures/modules/apoplast/shows/natures/pattern.r.HTML.py <==



pattern:
{
	"emblem": "",
	
	"affiliate": {
		"links": []
	},
	
	"USDA_food": {},
	"NIH_supp": {},
	
	"nature": {
		"identity": {
			"name": "",
			"UPC": "",
			"DSLD ID": "",
			"FDC ID": ""
		},
		
		"brand": {
			"name": ""
		},

		"measures": {
			
			#
			#	if a supp
			#
			"form": "form": {
				"unit": "Tablet",
				"amount": "90",
				
				#
				#	
				#
				"estimate": "no",
				"rounded": "up"
			},
			
			#
			#	For NIH supps these are necessary for
			#	calculating the mass.
			#
			#	{ defined, recommendations }
			#
			"recommendations": {
				"serving size": {
					"grams": {
						"fraction string": "28"
					}
				},
				"servings per package": ""
			},
			
			"energy": {
				"per package": {
					"calories": {
						"decimal string: "",
						"fraction string": ""
					},
					"joules": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			
			'''
				USDA:
					
				
				
				NIH:
					
				
			'''	
			"mass + mass equivalents, of measured ingredients ": {
				"per package": {
					"grams": {
						"decimal string: "",
						"fraction string": "",
						"grams sci note": [ "113.00", "e0" ]
					},
					"pounds": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			
			#
			#	non-essential, this is not present
			#	for most supplements.
			#
			"mass": {
				"per package": {
					"grams": {
						"decimal string: "",
						"fraction string": ""
					},
					"pounds": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			
			
			
			"mass equivalents": {
				"per package": {
					"grams": {
						"decimal string: "",
						"fraction string": ""
					},
					"pounds": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			},
			
			"volume": {
				"per package": {
					"liters": {
						"decimal string: "",
						"fraction string": ""
					}
				}
			}
		},
		
		"measured ingredients": {
			"essential nutrients grove": [{
				"name": "vitamin b",
				
				#
				#	essential nutrient
				#
				"essential": {
					"names": [ "vitamin b", "cobalamin" ],
					"includes": []
				},
			}],
			
			"shapes channel": [{
				
			}],
			
			"grove": [{
				"name": "vitamin b",
				
				"measures": {
					#
					#	This is probably almost always one or the other,
					#	but that would imply that it would be like,
					#	0 + 100 or 100 + 0, therefore, this is solid.
					#
					"mass + mass equivalents": {
						"per package": {
							"grams": {
								"decimal string": "",
								"fraction string": ""
							},
							"ounces": {
								
							}
						}
					},
					
					
					'''
						This is 2nd priority
					'''
					"mass": {
						"per package": {
							"grams": {
								"decimal string": "",
								"fraction string": ""
							},
							"ounces": {
								
							}
						}
					},
					
					'''
						This is 2nd priority
					'''
					"mass equivalent": {
						"per package": {
							"grams": {
								"equivalent": "DFE",
								"decimal string": "",
								"fraction string": ""
							}
						}
					},
					
					#
					#	if IU
					#
					"biological activity": {
						"per package": {
							"IU": {
								"decimal string": "",
								"fraction string": ""
							}
						}
					}
				},
				
				"includes": []
			}]
		},
		
		"unmeasured ingredients": {

			#
			#	USDA sends a string "ingredients"
			#
			"string": "",

			#
			#	NIH sends a list of "otherIngredients"
			#
			"list": []
		},

		"reference": [],
	},		


	#
	#	unique sections
	#

	#
	#	unique to NIH supps
	#
	"statements": []
	
	
	

	"calculated": {
		
		
		
		
		#
		#	this intermediary might be necessary
		#
		"quantified essential nutrients list": [],
		
		
		"quantified essential nutrients grove": [],
		
		#
		#	priority 2:
		#	
		#	based on shape.current_1
		#
		"quantified ingredients current": [],
	}
}
